@@ -2,7 +2,8 @@ use serde::{Deserialize, Serialize};
 
 use crate::definitions::{BranchesT, FullProductName, ProductGroupIdT, ProductIdT};
 
-// https://github.com/oasis-tcs/csaf/blob/master/csaf_2.0/prose/csaf-v2-editor-draft.md#322-product-tree-property
+/// [Product Tree](https://github.com/oasis-tcs/csaf/blob/master/csaf_2.0/prose/csaf-v2-editor-draft.md#322-product-tree-property)
+#[serde_with::skip_serializing_none]
 #[derive(Serialize, Deserialize, Debug)]
 pub struct ProductTree {
     pub branches: Option<BranchesT>,
@@ -11,6 +12,8 @@ pub struct ProductTree {
     pub relationships: Option<Vec<Relationship>>,
 }
 
+/// [Product Groups](https://github.com/oasis-tcs/csaf/blob/master/csaf_2.0/prose/csaf-v2-editor-draft.md#3223-product-tree-property---product-groups)
+#[serde_with::skip_serializing_none]
 #[derive(Serialize, Deserialize, Debug)]
 pub struct ProductGroup {
     pub group_id: ProductGroupIdT,
@@ -18,6 +21,7 @@ pub struct ProductGroup {
     pub summary: Option<String>,
 }
 
+/// [Relationships](https://github.com/oasis-tcs/csaf/blob/master/csaf_2.0/prose/csaf-v2-editor-draft.md#3224-product-tree-property---relationships)
 #[derive(Serialize, Deserialize, Debug)]
 pub struct Relationship {
     pub category: RelationshipCategory,
@@ -26,6 +30,7 @@ pub struct Relationship {
     pub relates_to_product_reference: ProductIdT,
 }
 
+/// [Relationships](https://github.com/oasis-tcs/csaf/blob/master/csaf_2.0/prose/csaf-v2-editor-draft.md#3224-product-tree-property---relationships)
 #[derive(Serialize, Deserialize, Debug)]
 #[serde(rename_all = "snake_case")]
 pub enum RelationshipCategory {
